/**********************************************************************

	--- TQt Architect generated file ---

	File: open_ksirc.h
	Last generated: Wed Jul 29 16:41:26 1998

 *********************************************************************/

#ifndef open_ksirc_included
#define open_ksirc_included

#include "open_ksircData.h"

#include <tqdict.h>

class KSircServer;

class open_ksirc : public open_ksircData
{
    Q_OBJECT
  TQ_OBJECT

public:

    open_ksirc
    (
        TQWidget* parent = NULL,
        const char* name = NULL
    );

    virtual ~open_ksirc();

protected slots:
  void setGroup( const TQString& );
  void setServer( const TQString& );
  void clickConnect();
  void clickCancel();
  void clickEdit();
  void passwordChanged( const TQString& );

private:
  void insertGroupList();
  void insertServerList( const char * );
  void setServerDesc( TQString );
  TQString encryptPassword( const TQString & );
  TQString decryptPassword( const TQString & );

signals:
//  void open_ksircprocess( const char *, int, const char * );
  void open_ksircprocess( KSircServer & );

};
#endif // open_ksirc_included
